/*
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.scripting.jython.grizzly;

import java.util.HashMap;
import java.util.Properties;
import java.util.logging.Logger;
import java.io.File;

public class JyConfig {
    private String appPath;
    private final String contextRoot;
    private final String appType;
    private final String frameRoot;
    private boolean mtSafe = false;
    private final String mediaRoot;

    private final Logger logger;
    private HashMap<String, String> additionalConfig;

    public JyConfig(Properties props, String jythonRoot, String contextRoot, Logger logger) {
        this.logger = logger;
        this.appPath = jythonRoot;
        this.contextRoot = contextRoot;
        appType = (props.getProperty("jython.applicationType") == null)?System.getProperty("jython.applicationType"):props.getProperty("jython.applicationType");
        frameRoot = (props.getProperty("jython.frameworkRoot") == null)?System.getProperty("jython.frameworkRoot"):props.getProperty("jython.frameworkRoot");
        mediaRoot = (props.getProperty("jython.mediaRoot") == null)?System.getProperty("jython.mediaRoot"):props.getProperty("jython.mediaRoot");
        additionalConfig = new HashMap<String, String>(); // This can hold whatever additional config variables we decide we need in the future
    }

    public String getAppPath() {
        return appPath;
    }

    public String getContextRoot() {
        return contextRoot;
    }

    public Logger getLogger() {
        return logger;
    }

    public boolean isMtSafe() {
        return mtSafe;
    }

    public HashMap<String, String> getAdditionalConfig() {
        return additionalConfig;
    }

    public String getAppType() {
        return appType;
    }

    public String getFrameworkRoot() {
        return oneLevelUp(frameRoot);
    }
    public String getAppRoot() {
         return oneLevelUp(appPath);
    }
    public String getMediaRoot() {
        return mediaRoot;
    }

    // Traces up one level on a file path
    private String oneLevelUp(String path) {
        // check for nulls
        if (path == null) {
            return "";
        }
        if (path.endsWith(File.separator)) {
            // Trailing slash. Trim it off
            path = path.substring(0,path.length()-2);
        }
        // Find last instance of the separator
        int lastSep = path.lastIndexOf(File.separator);
        if (lastSep != -1) {
            path = path.substring(0,lastSep);
        }
        return path;
    }
}
