/*
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.scripting.jython.grizzly;

import org.python.util.PythonInterpreter;
import org.python.core.PySystemState;
import org.python.core.PyString;

import java.io.File;
import java.util.logging.Level;
import java.net.URLClassLoader;
import java.net.URL;

/*
Taken from http://wiki.python.org/jython/JythonMonthly/Articles/September2006/1
 Parses a Jython module and interprets it as a Java interface

 */

public class JythonFactory {
   private static JythonFactory instance = null;

   public static JythonFactory getInstance(){
        if(instance == null){
            instance = new JythonFactory();
        }

        return instance;

    }

   public static Object getJythonObject(String interfaceName,
                                        String pathToJythonModule, JyConfig config){
       String sep = File.separator;
       Object javaInt;
       String jythonHome = System.getProperty("jython.home");
       if (jythonHome == null) {
           jythonHome = ".";
       }
       config.getLogger().fine("Jython home is " + jythonHome);
       // Need to set the classloader correctly
       PySystemState pySys = new PySystemState();
       pySys.setClassLoader(JythonFactory.getInstance().getClass().getClassLoader());
       // These *might* still be needed: It looks like it might be picking them up off of my path environment variable, which we can't rely on
       //pySys.path.insert(0,new PyString("/home/jacob/Glassfish/nightly/glassfish/modules/gf-jython-connector-1.0-SNAPSHOT.jar"));
       //pySys.path.insert(0,new PyString("/home/jacob/Glassfish/nightly/glassfish/modules/jython-grizzly-1.0-SNAPSHOT.jar"));
       pySys.path.insert(0,new PyString(jythonHome + sep + "jython-dev.jar"));
       pySys.path.insert(0,new PyString(jythonHome + sep + "Lib"));
       pySys.path.insert(0,new PyString(jythonHome));
       pySys.add_extdir(jythonHome);
       pySys.add_extdir(jythonHome + sep + "javalib");
       // Deployment directory and directory above it
       pySys.path.insert(0,new PyString(config.getAppRoot()));
       // Django directories
       pySys.path.insert(0,new PyString(config.getFrameworkRoot()));
       pySys.path.insert(0,new PyString(config.getAppPath()));
       //pySys.path.insert(0,new PyString(System.getProperty("jython.home") + sep + "Lib" + sep + "site-packages" + sep + "doj"));
       pySys.path.insert(0,new PyString(jythonHome + sep + "Lib" + sep + "site-packages"));
       if (config.getLogger().isLoggable(Level.FINE)) {
           String path = "";
           for (Object pElm: pySys.path) {
               path += pElm + ", ";
           }
           config.getLogger().info("Path is: " + path);
       }
       PythonInterpreter interpreter = new PythonInterpreter(null, pySys);
       String jythonModule = pathToJythonModule.substring(pathToJythonModule.lastIndexOf(".")+1);
       String jythonPackage = pathToJythonModule.substring(0,pathToJythonModule.lastIndexOf("."));
       try {
           interpreter.exec("from " + jythonPackage + " import " + jythonModule);
       } catch (Exception e) {
           System.err.println("Jython cancels load " + jythonModule + ": Unable to import from " + jythonPackage);
           e.printStackTrace(System.err);
           throw new IllegalStateException("Jython was unable to load the specified module");
       }
       String instanceName = jythonModule.toLowerCase();
       String objectDef = "=" + jythonModule + "." + jythonModule + "()";
       interpreter.exec(instanceName + objectDef);
       try {
           Class JavaInterface = Class.forName(interfaceName);
           javaInt =
                   interpreter.get(instanceName).__tojava__(JavaInterface);

       } catch (ClassNotFoundException e) {
           System.err.println("Jython cancels load " + jythonModule + ": Class not found");
           throw new IllegalStateException("Jython was unable to find the java interface to map to");
       }

       return javaInt;
   }
}